summaryrefslogtreecommitdiff
path: root/src/theory/fp/fp_converter.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/fp/fp_converter.h')
-rw-r--r--src/theory/fp/fp_converter.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/theory/fp/fp_converter.h b/src/theory/fp/fp_converter.h
index 6623f308c..e952699a7 100644
--- a/src/theory/fp/fp_converter.h
+++ b/src/theory/fp/fp_converter.h
@@ -45,7 +45,7 @@
#include "theory/rewriter.h"
#endif
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace fp {
@@ -97,7 +97,7 @@ class traits
typedef traits::bwt bwt;
/**
* Wrap the CVC4::Node types so that we can debug issues with this back-end
*/
class nodeWrapper : public Node
{
@@ -352,6 +352,6 @@ class FpConverter
} // namespace fp
} // namespace theory
-} // namespace CVC4
+} // namespace CVC5
#endif /* CVC4__THEORY__FP__THEORY_FP_H */
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -97,7 +97,7 @@ class traits
typedef traits::bwt bwt;
/**
- * Wrap the CVC4::Node types so that we can debug issues with this back-end
+ * Wrap the CVC5::Node types so that we can debug issues with this back-end
*/
class nodeWrapper : public Node